@@ -9,6 +9,7 @@ from .base import BaseFunction
 from ..properties import Constant
 from ..properties.property import Property
 from ..structures.cast_operator import CastOperator
+from ..structures.case import Case
 
 
 class Unaccent(BaseFunction):
@@ -16,7 +17,7 @@ class Unaccent(BaseFunction):
     TODO: only in PostgreSQL
     """
     obj: Literal['functions.Unaccent'] = 'functions.Unaccent'
-    property: Union[Property, BaseFunction, Constant, CastOperator]
+    property: Union[Property, BaseFunction, Constant, CastOperator, Case]
     alias: str = None
 
     def to_sql(self) -> str:
